OneginiBiometricCallback class

A callback of biometric authentication. Use this callback when user wants to authenticate by biometric and show biometric prompt.

Constructors

OneginiBiometricCallback()

Properties

api → UserClientApi
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

denyAuthenticationRequest() → Future<void>
Cancels authentication request. Used when user cancels authentication by biometric.
fallbackToPin() → Future<void>
Changes the authentication method from Biometric to PIN.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
showBiometricPrompt(OWBiometricMessages messages) → Future<void>
Show biometric prompt.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited