OneginiPinRegistrationCallback class

A callback for pin REGISTRATION.

Properties

api → UserClientApi
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

acceptAuthenticationRequest(String pin) → Future<void>
Accepts pin registration and sent pin to the OneginiSdk.
denyAuthenticationRequest() → Future<void>
Cancels pin registration request.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited