WrapperErrorCodes class

Errors from the flutter sdk, some of these errors can only occur on a single platform.

Constructors

WrapperErrorCodes()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

actionNotAllowedBrowserRegistrationCancel → const String
actionNotAllowedCustomRegistrationCancel → const String
alreadyInProgressMobileAuth → const String
iOS only. Android will throw actionAlreadyInProgress
biometricAuthenticationNotAvailable → const String
biometricAuthenticationNotInProgress → const String
Android only
configError → const String
Android only
genericError → const String
httpRequestErrorCode → const String
httpRequestErrorInternal → const String
httpRequestErrorNoResponse → const String
iOS only
idTokenNotAvailable → const String
invalidMultipartRequest → const String
Raised when a multipart request is invalid (e.g., both multipartData and body are set, used with GET, missing data/value, or method not supported)
invalidUrl → const String
notAuthenticatedImplicit → const String
notAuthenticatedUser → const String
notFoundAuthenticator → const String
notFoundIdentityProvider → const String
notFoundUserProfile → const String
notInProgressAuthentication → const String
notInProgressCustomRegistration → const String
notInProgressFingerprintAuthentication → const String
notInProgressOtpAuthentication → const String
notInProgressPinCreation → const String
onewelcomeSdkNotInitialized → const String
Android only