MultipartData class

A single part in a multipart/form-data request.

Provide either value (for text fields) or data (for binary/file parts). For file parts, fileName and contentType are recommended.

Constructors

MultipartData({String? name, String? value, Uint8List? data, String? fileName, String? contentType})
const

Properties

contentType String?
final
data Uint8List?
final
fileName String?
final
hashCode int
The hash code for this object.
no setterinherited
name String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited