RequestDetails class

Constructors

RequestDetails({required String path, required HttpRequestMethod method, Map<String, String>? headers, String? body, List<MultipartData>? multipartData})

Properties

body ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
headers ↔ Map<String, String>?
getter/setter pair
method ↔ HttpRequestMethod
getter/setter pair
multipartData ↔ List<MultipartData>?
On iOS, only HttpRequestMethod.post is supported with multipart; PUT and DELETE will return an error.
getter/setter pair
path ↔ String
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited