n2fEventInitCustomRegistration abstract method
Called when the InitCustomRegistration event occurs and a response should be given (only for two-step)
Implementation
void n2fEventInitCustomRegistration(OWCustomInfo? customInfo, String providerId);
Called when the InitCustomRegistration event occurs and a response should be given (only for two-step)
void n2fEventInitCustomRegistration(OWCustomInfo? customInfo, String providerId);