OWMultipartData class

Constructors

OWMultipartData({String? name, String? value, Uint8List? data, String? fileName, String? contentType})

Properties

contentType ↔ String?
getter/setter pair
data ↔ Uint8List?
getter/setter pair
fileName ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
name ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value ↔ String?
getter/setter pair

Methods

encode() → Object
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

decode(Object result) → OWMultipartData