OWRequestDetails class

Constructors

OWRequestDetails({required String path, required HttpRequestMethod method, Map<String?, String?>? headers, String? body, List<OWMultipartData?>? multipartData})

Properties

body ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
headers ↔ Map<String?, String?>?
getter/setter pair
method ↔ HttpRequestMethod
getter/setter pair
multipartData ↔ List<OWMultipartData?>?
getter/setter pair
path ↔ String
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

encode() → Object
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

decode(Object result) → OWRequestDetails