OWRequestResponse class

Constructors

OWRequestResponse({required Map<String?, String?> headers, required String body, required bool ok, required int status})

Properties

body ↔ String
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
headers ↔ Map<String?, String?>
getter/setter pair
ok ↔ bool
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status ↔ int
getter/setter pair

Methods

encode() → Object
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

decode(Object result) → OWRequestResponse