UserClient class

Сlass with basic methods available to the developer.

Constructors

UserClient(UserClientApi api)

Properties

api → UserClientApi
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

authenticateDevice(List<String>? scopes) → Future<void>
todo removed boolean return update docu
authenticateUser(String profileId, OWAuthenticatorType? authenticatorType) → Future<OWRegistrationResponse>
Starts authentication flow.
authenticateUserImplicitly(String profileId, List<String>? scopes) → Future<void>
todo removed string return update docu
changePin() → Future<void>
Starts change pin flow.
deregisterBiometricAuthenticator() → Future<void>
deregisterUser(String profileId) → Future<void>
Deletes the user.
enrollMobileAuthentication() → Future<void>
Enroll for MobileAuthentication (enable OTP)
getAccessToken() → Future<String>
getAppToWebSingleSignOn(String url) → Future<OWAppToWebSingleSignOn>
Single sign on the user web page.
getAuthenticatedUserProfile() → Future<OWUserProfile>
getBiometricAuthenticator(String profileId) → Future<OWAuthenticator>
getIdentityProviders() → Future<List<OWIdentityProvider>>
Returns a list of available identity providers.
getIdToken() → Future<String>
getPreferredAuthenticator(String profileId) → Future<OWAuthenticator>
getRedirectUrl() → Future<String>
getUserProfiles() → Future<List<OWUserProfile>>
User profiles
handleMobileAuthWithOtp(String data) → Future<void>
Respond to mobile authentication with OTP
handleRegisteredUserUrl(String url, {WebSignInType signInType = WebSignInType.insideApp}) → Future<void>
Start browser Registration logic
logout() → Future<void>
Method for log out
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
refreshStatelessSession() → Future<void>
registerBiometricAuthenticator() → Future<void>
registerStatelessUser(String? identityProviderId, List<String>? scopes) → Future<OWRegistrationResponse>
registerUser(String? identityProviderId, List<String>? scopes) → Future<OWRegistrationResponse>
Start registration flow.
setPreferredAuthenticator(OWAuthenticatorType authenticatorType) → Future<void>
Set preferred authenticator todo removed boolean return update docu
toString() → String
A string representation of this object.
inherited
validatePinWithPolicy(String pin) → Future<void>
todo removed boolean return update docu

Operators

operator ==(Object other) → bool
The equality operator.
inherited